import 'package:flutter/material.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/getWidgets/UikCard/UikCardProps.dart';
import 'package:ui_sdk/getWidgets/uikImageOverlay/UikImageOverlay.dart';
import 'package:ui_sdk/getWidgets/uikImageOverlay/UikImageOverlayProps.dart';
import 'package:ui_sdk/getWidgets/uikPosition/UikPositon.dart';

class UikCard extends UikWidget {
  WidgetType _widgetType;
  UikCardProps _uikCardProps;

  UikCard(this._widgetType, this._uikCardProps)
      : super(_widgetType, _uikCardProps);

  @override
  _uikCardState createState() => _uikCardState(_uikCardProps);
}

class _uikCardState extends State<UikCard> {
  UikCardProps _uikCardProps;

  _uikCardState(this._uikCardProps);

  static const double _defaultElevation = 1;
  static const Clip _defaultClipBehavior = Clip.none;

  @override
  Widget build(BuildContext context) {
    final CardTheme cardTheme = CardTheme.of(context);

    final Widget cardChild = Padding(
      padding: _uikCardProps.padding,
      child: Column(
        children: <Widget>[
          _uikCardProps.titlePosition == UikPosition.start
              ? _uikCardProps.title ?? Container()
              : _uikCardProps.showImage != false
                  ? ClipRRect(
                      // ignore: avoid_as
                      borderRadius: _uikCardProps.borderRadius
                              as BorderRadius? ??
                          const BorderRadius.vertical(top: Radius.circular(4)),
                      child: _uikCardProps.image,
                    )
                  : Container(),
          _uikCardProps.titlePosition == UikPosition.start
              ? _uikCardProps.showImage != false
                  ? Container(child: _uikCardProps.image)
                  : Container()
              : _uikCardProps.title ?? Container(),
          Padding(
            padding: _uikCardProps.padding,
            child: _uikCardProps.content ?? Container(),
          ),
          _uikCardProps.buttonBar ?? Container(),
        ],
      ),
    );

    final Widget? overlayImage = _uikCardProps.overlayImage;

    return Container(
      height: _uikCardProps.height,
      margin:
          _uikCardProps.margin ?? cardTheme.margin ?? const EdgeInsets.all(16),
      decoration: _uikCardProps.gradient != null
          ? BoxDecoration(
              gradient: _uikCardProps.gradient,
              borderRadius: _uikCardProps.borderRadius ??
                  const BorderRadius.all(Radius.circular(4)),
            )
          : null,
      child: _uikCardProps.gradient == null
          ? Material(
              type: MaterialType.card,
              color: _uikCardProps.color ??
                  cardTheme.color ??
                  Theme.of(context).cardColor,
              elevation: _uikCardProps.elevation ??
                  cardTheme.elevation ??
                  _defaultElevation,
              shape: _uikCardProps.shape ??
                  cardTheme.shape ??
                  const RoundedRectangleBorder(
                    borderRadius: BorderRadius.all(Radius.circular(4)),
                  ),
              borderOnForeground: _uikCardProps.borderOnForeground,
              clipBehavior: _uikCardProps.clipBehavior ??
                  cardTheme.clipBehavior ??
                  _defaultClipBehavior,
              child: _uikCardProps.showOverlayImage == false
                  ? cardChild
                  : overlayImage,
            )
          : _uikCardProps.showOverlayImage == false
              ? cardChild
              : overlayImage,
    );
  }
}
